@@ -29,28 +29,16 @@ API_SECRET = os.getenv('API_SECRET')
 BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
 PLATFORM_ROUTE = os.getenv("PLATFORM_ROUTE")
 APP_ID = os.getenv('APP_ID')
+API_TIME_STACKS = int(os.getenv('API_TIME_STACKS', 5))
 
 from .renderer.excel import ExcelRenderer
 storage_name = os.getenv('STORAGE_NAME')
 
 global ACCESS_KEY_ID, SECRET_ACCESS_KEY, REGION_NAME, BUCKET_NAME
-ACCESS_KEY_ID = ''
-SECRET_ACCESS_KEY = ''
-REGION_NAME = ''
-BUCKET_NAME = ''
-
-if storage_name == 's3_storage':
-    ACCESS_KEY_ID = os.getenv('AWS_ACCESS_KEY_ID')
-    SECRET_ACCESS_KEY = os.getenv('AWS_SECRET_ACCESS_KEY')
-    REGION_NAME = os.getenv('REGION_NAME')
-    BUCKET_NAME = os.getenv('S3_BUCKET_NAME')
-elif storage_name == 'ceph_storage':
-    ACCESS_KEY_ID = os.getenv('CEPH_ACCESS_KEY_ID')
-    SECRET_ACCESS_KEY = os.getenv('CEPH_SECRET_ACCESS_KEY')
-    BUCKET_NAME = os.getenv('CEPH_BUCKET_NAME')
-    REGION_NAME = os.getenv('CEPH_REGION_NAME')
-else:
-    logger.info("No storages are found")
+ACCESS_KEY_ID = os.getenv('ACCESS_KEY_ID', '')
+SECRET_ACCESS_KEY = os.getenv('SECRET_ACCESS_KEY', '')
+REGION_NAME = os.getenv('REGION_NAME', '')
+BUCKET_NAME = os.getenv('BUCKET_NAME', '')
 
 
 def get_token():
@@ -142,6 +130,10 @@ def call_post_requests(url, params=None, data=None, verify=True):
     return call_requests('POST', url, params, data, verify=verify)
 
 
+def call_put_requests(url, params=None, data=None, verify=True):
+    return call_requests('PUT', url, params, data, verify=verify)
+
+
 def login_call_get_requests(url, params=None, verify=True):
     return login_call_requests('GET', url, params, verify=verify)
 
@@ -242,7 +234,8 @@ def upload_to_s3(content, location):
     try:
         s3.Bucket(BUCKET_NAME).put_object(Body=content,
                                              Key=location)
-        return object_url
+        #return object_url
+        return location
     except Exception:
         pass
     
@@ -261,15 +254,20 @@ def generate_pdf(analysis_run):
         'size': 'A4'
     }
 
+    api_proce_before_time = time.time()
     res = requests.post(url, data=data).json()
-    logger.info('Pdf response is: %s', res['Location'])
-    return res['Location']
+    api_proce_after_time = time.time()
+    api_proce_diff = diff_sec(api_proce_before_time, api_proce_after_time)
+    if api_proce_diff > API_TIME_STACKS:
+        logging.info('Pdf response is took %d (greater than %d) seconds', api_proce_diff, API_TIME_STACKS)
+    logger.info('Pdf response is: %s', res['key'])
+    return res['key']
 
 
 
-def generate_excel(analysis_run, orgId, integrationId, file_name=None):
+def generate_excel(analysis_run, orgId, integrationId, excel_data, report_gen_start_time, report_gen_completed_time, file_name=None):
     try:
-        excel_renderer = ExcelRenderer(analysis_run, orgId, integrationId)
+        excel_renderer = ExcelRenderer(analysis_run, orgId, integrationId, excel_data, report_gen_start_time, report_gen_completed_time)
         workbook = excel_renderer.render()
     except Exception as ex:
         raise ex
@@ -283,9 +281,31 @@ def generate_excel(analysis_run, orgId, integrationId, file_name=None):
 
     return output
 
-    
 
-def update_results_url(gen_start_time, analysisRunId, tenantId, integrationId, json_result_url=None, gen_completed_time=None, excel_result_url=None, pdf_result_url=None, status=None):
+def diff_sec(st, et):
+    difference = int(et - st)
+    return difference
+
+
+def update_status_url(analysisRunId, tenantId, integrationId, genStime, genEtime, status=None):
+
+    url = BASE_API_URL + f'/analytics/api/v7/tenants/{tenantId}/{integrationId}/runs/{analysisRunId}'
+    data={
+            "status" : status,
+            "runDurStartDate" : genStime,
+            "runDurEndDate" : genEtime
+        }
+    
+    api_proce_before_time = time.time()
+    res = call_put_requests(url , data=json.dumps(data), verify=False);
+    api_proce_after_time = time.time()
+    api_proce_diff = diff_sec(api_proce_before_time, api_proce_after_time)
+    if api_proce_diff > API_TIME_STACKS:
+        logging.info('Status update response took %d (greater than %d) seconds', api_proce_diff, API_TIME_STACKS)
+    logger.info('Status update response is %s', res)
+
+
+def update_results_url(gen_start_time, analysisRunId, tenantId, integrationId, json_result_url=None, gen_completed_time=None, excel_result_url=None, pdf_result_url=None, failure_reason=None, status=None):
 
     url = BASE_API_URL + f'/analytics/api/v7/tenants/{tenantId}/{integrationId}/runs/{analysisRunId}'
     
@@ -295,7 +315,8 @@ def update_results_url(gen_start_time, analysisRunId, tenantId, integrationId, j
                 "resultUrl" : json_result_url,
                 "filePath" : excel_result_url,
                 "repGenStartTime" : gen_start_time,
-                "repGenEndTime" : gen_completed_time
+                "repGenEndTime" : gen_completed_time,
+                "failureReason" : failure_reason
         }
     else:
         data={
@@ -303,10 +324,16 @@ def update_results_url(gen_start_time, analysisRunId, tenantId, integrationId, j
                 "resultUrl" : json_result_url,
                 "filePath" : pdf_result_url,
                 "repGenStartTime" : gen_start_time,
-                "repGenEndTime" : gen_completed_time
+                "repGenEndTime" : gen_completed_time,
+                "failureReason" : failure_reason
         }
 
-    res = call_post_requests(url , data=json.dumps(data), verify=False);
+    api_proce_before_time = time.time()
+    res = call_put_requests(url , data=json.dumps(data), verify=False);
+    api_proce_after_time = time.time()
+    api_proce_diff = diff_sec(api_proce_before_time, api_proce_after_time)
+    if api_proce_diff > API_TIME_STACKS:
+        logging.info('Database update response took %d (greater than %d) seconds', api_proce_diff, API_TIME_STACKS)
     logger.info('Database update response is %s', res)
 
 
@@ -319,7 +346,7 @@ def upload_excel_s3(local_file, bucket, s3_file):
         logger.info('Upload successful, result url is %s', url)
         
         delete_excel_file(local_file)
-        return url
+        return s3_file
     except FileNotFoundError:
         logger.info('File was not found')
         return False
@@ -338,13 +365,13 @@ def delete_excel_file(source_path):
 
 
 #Generate excel file
-def generate_excel_file(run_id, orgId, integrationId):
+def generate_excel_file(run_id, orgId, integrationId, report_gen_start_time, report_gen_completed_time):
     logger.info('Entered into excel generation process')
     excel_data=get_result_by_run(run_id, 'excel-data', {})
     reportname = f"{APP_ID.lower()}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
-    generate_excel(excel_data, orgId, integrationId, filepath)
-    excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/excel/' + reportname
+    generate_excel(run_id, orgId, integrationId, excel_data, report_gen_start_time, report_gen_completed_time, filepath)
+    excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
     
     excel_url = upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
     return excel_url
